{ pkgs, config, ... }:

{

  imports = [
    ./drives.nix
    ./keyboard.nix
    ./network.nix
    ./wireless.nix
    ./power.nix
    ./opengl.nix
    ./sound.nix
  ];

  environment.systemPackages = with pkgs; [
    acpi
  ];

  console.keyMap = "dvorak";

  hardware.bluetooth.enable = false;

  hardware.opengl.driSupport32Bit = true;

  system.stateVersion = "20.09";

  boot.supportedFilesystems = [ "ntfs" ];
  boot = {
    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };
    initrd = {
      availableKernelModules = [
        "ehci_pci" "ata_piix" "usbhid"
        "usb_storage" "sd_mod" "sdhci_pci"
      ];
      kernelModules = [ "dm-snapshot" "i915" ];
    };
    kernelModules = [ "kvm-intel" "acpi_call" ];
    extraModulePackages = with config.boot.kernelPackages; [ acpi_call ];
  };

}
